/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.plugin.config;

import java.util.ArrayList;
import java.util.List;

import org.tinygroup.plugin.impl.BasePlugin;

import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;

@XStreamAlias("plugin")
public class PluginInfo {
	private static final int MAX_LEVEL = 99;
	@XStreamAsAttribute
	private String id;
	@XStreamAsAttribute
	private String version;
	@XStreamAsAttribute
	private String type;// 接口类名
	@XStreamAsAttribute
	private int level;// 级别，1-99,越小级别越高，级别虽1的，属于内核级别，不允许停止操作，且自动启动，如果不指定作为99计算
	@XStreamAlias("plugin-services")
	private List<PluginService> pluginServices;
	@XStreamAlias("plugin-dependencies")
	private List<PluginDependency> pluginDependencies;
	private String description;
	@XStreamAlias("plugin-configuration")
	private PluginConfiguration pluginConfiguration;


	public PluginConfiguration getPluginConfiguration() {
		if (pluginConfiguration == null) {
			pluginConfiguration = new PluginConfiguration();
		}
		return pluginConfiguration;
	}

	public int getLevel() {
		if (level <= 0 || level > MAX_LEVEL) {
			return MAX_LEVEL;
		}
		return level;
	}

	public void setLevel(int level) {
		this.level = level;
	}

	public void setPluginConfiguration(PluginConfiguration pluginConfiguration) {
		this.pluginConfiguration = pluginConfiguration;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public String getVersion() {
		return version;
	}

	public void setVersion(String version) {
		this.version = version;
	}

	public String getType() {
		if (type == null) {
			type = BasePlugin.class.getName();
		}
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public List<PluginService> getPluginServices() {
		if (pluginServices == null) {
			pluginServices = new ArrayList<PluginService>();
		}
		return pluginServices;
	}

	public void setPluginServices(List<PluginService> pluginServices) {
		this.pluginServices = pluginServices;
	}

	public List<PluginDependency> getPluginDependencies() {
		if (pluginDependencies == null) {
			pluginDependencies = new ArrayList<PluginDependency>();
		}
		return pluginDependencies;
	}

	public void setPluginDependencies(List<PluginDependency> pluginDependencies) {
		this.pluginDependencies = pluginDependencies;
	}

}
